=========================================================
networking-ovn - OpenStack Neutron integration with OVN
=========================================================

OVN provides virtual networking for Open vSwitch and is a component of the Open
vSwitch project.  This project provides integration between OpenStack Neutron
and OVN.

* Free software: Apache license
* Source: http://git.openstack.org/cgit/openstack/networking-ovn
* Bugs: http://bugs.launchpad.net/networking-ovn
* Mailing list:
  http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev
* IRC: #openstack-neutron-ovn on Freenode.
* Docs: http://docs.openstack.org/developer/networking-ovn/

The original OVN project announcement can be found here:

* http://networkheresy.com/2015/01/13/ovn-bringing-native-virtual-networking-to-ovs/

The OVN architecture is described here:

* http://openvswitch.org/support/dist-docs/ovn-architecture.7.html

OVN includes a tutorial to help with understanding how it works:

* https://github.com/openvswitch/ovs/blob/master/tutorial/OVN-Tutorial.md

OVN DB schemas and other man pages:

* http://openvswitch.org/support/dist-docs/ovn-nb.5.html
* http://openvswitch.org/support/dist-docs/ovn-sb.5.html
* http://openvswitch.org/support/dist-docs/ovn-nbctl.8.html
* http://openvswitch.org/support/dist-docs/ovn-sbctl.8.html
* http://openvswitch.org/support/dist-docs/ovn-northd.8.html
* http://openvswitch.org/support/dist-docs/ovn-controller.8.html
* http://openvswitch.org/support/dist-docs/ovn-controller-vtep.8.html

The openvswitch web page includes a list of presentations, some of which are
about OVN:

* http://openvswitch.org/support/
* OVN talk at OpenStack Summit in Austin, Spring 2016
  * https://www.youtube.com/watch?v=okralc7LrZo
* OVN Project Update at the OpenStack Summit in Tokyo, Fall 2015
  * http://openvswitch.org/support/slides/OVN_Tokyo.pdf
  * https://www.youtube.com/watch?v=3IrG2xghJjs
* OVN at OpenStack Summit in Vancouver, Sping 2015
  * http://openvswitch.org/support/slides/OVN-Vancouver.pdf
  * https://www.youtube.com/watch?v=kEzXTq2fPDg
* OVS Conference 2015
  * https://www.youtube.com/watch?v=JLGZOYi_Cqc

These blog resources may also help with testing and understanding OVN:

* http://galsagie.github.io/2015/11/23/ovn-l3-deepdive/
* http://blog.russellbryant.net/2015/10/22/openstack-security-groups-using-ovn-acls/
* http://galsagie.github.io/sdn/openstack/ovs/2015/05/30/ovn-deep-dive/
* http://blog.russellbryant.net/2015/05/14/an-ez-bake-ovn-for-openstack/
* http://galsagie.github.io/sdn/openstack/ovs/2015/04/26/ovn-containers/
* http://blog.russellbryant.net/2015/04/21/ovn-and-openstack-status-2015-04-21/
* http://blog.russellbryant.net/2015/04/08/ovn-and-openstack-integration-development-update/
